summaryrefslogtreecommitdiffstats
path: root/umbrello/make-umbrello-release.sh
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/make-umbrello-release.sh')
-rwxr-xr-xumbrello/make-umbrello-release.sh24
1 files changed, 12 insertions, 12 deletions
diff --git a/umbrello/make-umbrello-release.sh b/umbrello/make-umbrello-release.sh
index 84429ad0..812291f0 100755
--- a/umbrello/make-umbrello-release.sh
+++ b/umbrello/make-umbrello-release.sh
@@ -1,6 +1,6 @@
#!/bin/sh
#
# Make a release from the current branches/KDE/3.5/kdesdk/umbrello
#
# Run this script as follows:
# . make-umbrello-release.sh [BRANCH_VERSION]
@@ -8,7 +8,7 @@
# @todo Create release from trunk if BRANCH_VERSION not given.
# Note: trunk uses the cmake based build process.
#
# The script creates a directory, /tmp/kdesdk, which is used
# as the work area for building the release.
# The release tarfile will be placed in the current working dir.
# The release version is taken from the VERSION file.
@@ -22,12 +22,12 @@ version=`grep "^[1-9]" VERSION`
udir=umbrello-$version
svnroot=svn://anonsvn.kde.org:/home/kde/branches/KDE/$branchver
cd /tmp
-svn co -N $svnroot/kdesdk
-cd kdesdk
-svn co $svnroot/kdesdk/umbrello $udir
+svn co -N $svnroot/tdesdk
+cd tdesdk
+svn co $svnroot/tdesdk/umbrello $udir
svn co $svnroot/kde-common/admin $udir/admin
-svn co -N $svnroot/kdesdk/doc $udir/doc
-svn co $svnroot/kdesdk/doc/umbrello $udir/doc/umbrello
+svn co -N $svnroot/tdesdk/doc $udir/doc
+svn co $svnroot/tdesdk/doc/umbrello $udir/doc/umbrello
cp -p Makefile.cvs $udir/
cd $udir
mv configure.in.in configure.in.in.orig
@@ -39,19 +39,19 @@ cat configure.in.in.orig >> configure.in.in
rm configure.in.in.orig
perl -p -e 's@umbrello/VERSION@VERSION@g' -i `find umbrello -name Makefile.am`
cd /tmp
-log=/tmp/kdesdk/svn2dist.log
-$origdir/../scripts/svn2dist kdesdk $udir -n umbrello --admin-dir kdesdk/$udir/admin \
+log=/tmp/tdesdk/svn2dist.log
+$origdir/../scripts/svn2dist tdesdk $udir -n umbrello --admin-dir tdesdk/$udir/admin \
--svn-root svn://anonsvn.kde.org/home/kde/branches/stable --log=$log -o
-mv umbrello/po kdesdk/$udir/
+mv umbrello/po tdesdk/$udir/
rm -rf umbrello
-cd kdesdk/$udir
+cd tdesdk/$udir
make -f Makefile.cvs
cd ..
tarfile=${udir}.tar.bz2
tar cfvj $tarfile --exclude=.svn --exclude=autom4te.cache $udir
mv $tarfile $origdir/
cd $origdir
-# rm -rf /tmp/kdesdk
+# rm -rf /tmp/tdesdk
echo upload $tarfile to upload.sf.net
echo wput $tarfile ftp://upload.sf.net/incoming/
@@ -1,6 +1,6 @@
#!/bin/sh
#
-# Make a release from the current branches/KDE/3.5/kdesdk/umbrello
+# Make a release from the current branches/KDE/3.5/tdesdk/umbrello
#
# Run this script as follows:
@@ -8,7 +8,7 @@
# Note: trunk uses the cmake based build process.
#
-# The script creates a directory, /tmp/kdesdk, which is used
+# The script creates a directory, /tmp/tdesdk, which is used
# as the work area for building the release.
# The release tarfile will be placed in the current working dir.